# swagger-client
# Overview  The DataGalaxy API gives you access to CRUD actions on your metamodel, users and licenses.  Our API is organized around REST. It accepts and returns JSON-encoded data, and uses standard HTTP response codes, verbs and authentication with access tokens.  To get the full picture of DataGalaxy, please feel free to consult our <a href='https://datagalaxy.freshdesk.com/solution/articles/35000131583--basics-datagalaxy-s-main-concepts-/en' target='_new'>online documentation.</a><br/> Have a look at our <a href='https://datagalaxy.freshdesk.com/en/support/solutions/articles/35000151096--quick-start-datagalaxy-public-api-v2' target='_new'>step by step guide</a> for a quick start on how to use our API.  ## Response Status Codes  | Status Code  | Description       | Notes | | ------------ | ----------------- | ----- | | 200          | OK                | The request was successful | | 400          | Bad Request       | Incoming request contains parameters that might not be valid | | 401          | Unauthorized      | The supplied credentials, if any, are not sufficient to access the resource | | 404          | Not Found         | The requested resource is not found | | 429          | Too Many Requests | Too many requests have been (Rate limiting) | | 500          | Server Error      | The server could not return the representation due to an internal server error | | 501          | Not Implemented   | The requested operation is not supported (e.g. supports GET but not POST etc.) |  ## Rate Limits  The DataGalaxy API has 2 kinds of limitations: rate limiting and throttling.  <b>Pro tip:</b> You can track your rate limiting status with the response header `X-RateLimit-Remaining`. It will display how many requests you can send until the next reset.  | Method        | Rate                 | Note | | ------------- | -------------------- | ---- | | Rate limiting | 7200 requests / hour | When exceeded, your IP will be blocked for 15 minutes. | | Throttling    | 2 requests / second  | When exceeded, each request will be delayed by 500ms. | | Payload size  | 100 MB               | When exceeded, request will be rejected. |  ## Pagination  All routes returning lists share the same pagination format. These routes take two optional parameters as querystrings: <code>limit</code> and <code>page</code>.<br>  | QueryString | Definition | |------------ | ---------- | | limit       | Integer ranging from 1 to 5000. It sets the maximum amount of objects per page. Default value is 20. | | page        | Integer starting at 1. It determines the page returned by the request. Default value is 1. |  The response payload contains 5 properties:  | Property  | Definition | | --------- | ---------- | | pages     | Total number of pages. | | total     | Number of objects returned. | | total_sum | Sum of all existing objects. | | next_page | URL of the next page. <i>Value will be null if there is none.</i> | | results   | List of objects. |  # Authentication  The DataGalaxy API uses <b>Bearer Authentication</b> to authenticate requests. Every request must contain an <code>Authorization</code> header with, either an <i>AccessToken</i> or an <i>IntegrationToken</i>.  ## AccessToken  Here is a quick example using CURL:  <pre><code>curl -X GET \"https://api.datagalaxy.com/v2/workspaces\" -H \"Authorization: Bearer <i>AccessToken</i>\"</code></pre>  The first steps of our <a href='https://datagalaxy.freshdesk.com/en/support/solutions/articles/35000151096--quick-start-datagalaxy-public-api-v2' target='_new'>quick start guide</a> will give you instructions to obtain your <code>accesstoken</code>.  ## IntegrationToken  An integration token can be generated from the \"Integration\" page on the DataGalaxy Administration space.  <pre><code>curl -X GET \"https://api.datagalaxy.com/v2/workspaces\" -H \"Authorization: Bearer <i>IntegrationToken</i>\"</code></pre>  # Changelog  The DataGalaxy Developer API is updated frequently with new features, improvements and fixes.  All these changes will be documented in our <button><a href='/v2/documentation/changelog' target='_blank'><b>changelog</b></a></button>.  # Documentation layout  We provide two API documentation layouts:  - [Default layout](/v2/documentation)<br> This layout displays informations in a modern way and contains more informations about requests parameters - [Swagger layout](/v2/documentation/old)<br> This is our legacy layout. It's main perk is the \"Try it\" feature which let's you send requests directly from the documentation.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.12.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = [swagger_client.AttributeBulkCreationBody()] # list[AttributeBulkCreationBody] | 

try:
    # Bulk create attributes
    api_response = api_instance.bulk_create_attribute(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->bulk_create_attribute: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = [swagger_client.AttributeBulkUpdateBody()] # list[AttributeBulkUpdateBody] | 

try:
    # Bulk edit attributes
    api_response = api_instance.bulk_update_attribute(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->bulk_update_attribute: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = swagger_client.AttributeCreationBody() # AttributeCreationBody | 
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | Specifies the <code>dataType</code> this attribute will be associated with

try:
    # Create a custom attribute
    api_response = api_instance.create_attribute(body, data_type)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->create_attribute: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = swagger_client.AttributesValuesBody1() # AttributesValuesBody1 | 
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | 
attribute_key = swagger_client.AttributeKey() # AttributeKey | 

try:
    # Add attribute values
    api_response = api_instance.create_attribute_values(body, data_type, attribute_key)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->create_attribute_values: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | Specifies the <code>dataType</code> associated with an attribute
attribute_key = swagger_client.AttributeKey() # AttributeKey | Unique attribute identifier. Can be found with GET /attributes or when creating attributes with POST /attributes

try:
    # Delete a custom attribute
    api_response = api_instance.delete_attribute(data_type, attribute_key)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->delete_attribute: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | 
attribute_key = swagger_client.AttributeKey() # AttributeKey | 

try:
    # List attribute values
    api_response = api_instance.get_attribute_values(data_type, attribute_key)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->get_attribute_values: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | 

try:
    # Return a list of attributes
    api_response = api_instance.get_attributes(data_type)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->get_attributes: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
version_id = swagger_client.VersionId() # VersionId | 
module_name = 'module_name_example' # str |  (optional)
limit = 20 # float |  (optional) (default to 20)
page = 1 # float |  (optional) (default to 1)

try:
    # List of available attributes
    api_response = api_instance.get_supported_attributes(version_id, module_name=module_name, limit=limit, page=page)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->get_supported_attributes: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
limit = 20 # float |  (optional) (default to 20)
page = 1 # float |  (optional) (default to 1)
color = 'color_example' # str |  (optional)
is_native = true # bool |  (optional)
is_active = true # bool |  (optional)
is_user_suggestion_enabled = true # bool |  (optional)

try:
    # List available tags
    api_response = api_instance.get_tags(limit=limit, page=page, color=color, is_native=is_native, is_active=is_active, is_user_suggestion_enabled=is_user_suggestion_enabled)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->get_tags: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = [swagger_client.TagsBody()] # list[TagsBody] | 

try:
    # Create tag
    api_response = api_instance.post_tags(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->post_tags: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = swagger_client.AttributeUpdateBody() # AttributeUpdateBody | 
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | Specifies the <code>dataType</code> associated with an attribute
attribute_key = 'attribute_key_example' # str | Unique attribute identifier. Can be found with GET /attributes or when creating attributes with POST /attributes

try:
    # Update an attribute
    api_response = api_instance.update_attribute(body, data_type, attribute_key)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->update_attribute: %s\n" % e)


# create an instance of the API class
api_instance = swagger_client.AttributesApi(swagger_client.ApiClient(configuration))
body = swagger_client.AttributesValuesBody() # AttributesValuesBody | 
data_type = swagger_client.AttributeDataTypeEnum() # AttributeDataTypeEnum | 
attribute_key = swagger_client.AttributeKey() # AttributeKey | 

try:
    # Update attribute values
    api_response = api_instance.update_attribute_values(body, data_type, attribute_key)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AttributesApi->update_attribute_values: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AttributesApi* | [**bulk_create_attribute**](docs/AttributesApi.md#bulk_create_attribute) | **POST** /attributes/bulk | Bulk create attributes
*AttributesApi* | [**bulk_update_attribute**](docs/AttributesApi.md#bulk_update_attribute) | **PUT** /attributes/bulk | Bulk edit attributes
*AttributesApi* | [**create_attribute**](docs/AttributesApi.md#create_attribute) | **POST** /attributes/{dataType} | Create a custom attribute
*AttributesApi* | [**create_attribute_values**](docs/AttributesApi.md#create_attribute_values) | **POST** /attributes/values | Add attribute values
*AttributesApi* | [**delete_attribute**](docs/AttributesApi.md#delete_attribute) | **DELETE** /attributes/{dataType}/{attributeKey} | Delete a custom attribute
*AttributesApi* | [**get_attribute_values**](docs/AttributesApi.md#get_attribute_values) | **GET** /attributes/values | List attribute values
*AttributesApi* | [**get_attributes**](docs/AttributesApi.md#get_attributes) | **GET** /attributes | Return a list of attributes
*AttributesApi* | [**get_supported_attributes**](docs/AttributesApi.md#get_supported_attributes) | **GET** /supportedAttributes/{versionId} | List of available attributes
*AttributesApi* | [**get_tags**](docs/AttributesApi.md#get_tags) | **GET** /tags | List available tags
*AttributesApi* | [**post_tags**](docs/AttributesApi.md#post_tags) | **POST** /tags | Create tag
*AttributesApi* | [**update_attribute**](docs/AttributesApi.md#update_attribute) | **PUT** /attributes/{dataType}/{attributeKey} | Update an attribute
*AttributesApi* | [**update_attribute_values**](docs/AttributesApi.md#update_attribute_values) | **PUT** /attributes/values | Update attribute values
*AuthenticationApi* | [**generate**](docs/AuthenticationApi.md#generate) | **GET** /credentials | Generate an accessToken.
*AuthenticationApi* | [**regenerate**](docs/AuthenticationApi.md#regenerate) | **GET** /credentials/regenerate | Regenerate an integrationToken.
*CommentsApi* | [**delete_comment**](docs/CommentsApi.md#delete_comment) | **DELETE** /comments/{versionId}/{entityId}/{commentId} | Delete a comment
*CommentsApi* | [**get_comment**](docs/CommentsApi.md#get_comment) | **GET** /comments/{versionId}/{entityId} | Return a list of comments.
*CommentsApi* | [**post_comment**](docs/CommentsApi.md#post_comment) | **POST** /comments/{versionId}/{entityId} | Create a comment.
*CommentsApi* | [**put_comment**](docs/CommentsApi.md#put_comment) | **PUT** /comments/{versionId}/{entityId}/{commentId} | Update a comment
*ContainersApi* | [**create_bulk_containers**](docs/ContainersApi.md#create_bulk_containers) | **POST** /containers/bulk/{versionId}/{parentId} | Bulk create containers.
*ContainersApi* | [**create_container**](docs/ContainersApi.md#create_container) | **POST** /containers/{versionId}/{parentId} | Create a container.
*ContainersApi* | [**delete_bulk_container**](docs/ContainersApi.md#delete_bulk_container) | **DELETE** /containers/bulk/{versionId} | Bulk delete containers
*ContainersApi* | [**delete_container**](docs/ContainersApi.md#delete_container) | **DELETE** /containers/{versionId}/{containerId} | Delete a container.
*ContainersApi* | [**get_container**](docs/ContainersApi.md#get_container) | **GET** /containers/{versionId}/{containerId} | Return the details of a container.
*ContainersApi* | [**get_containers_list**](docs/ContainersApi.md#get_containers_list) | **GET** /containers | Return a list of containers.
*ContainersApi* | [**get_types**](docs/ContainersApi.md#get_types) | **GET** /containers/types | List the container types.
*ContainersApi* | [**update_bulk_containers**](docs/ContainersApi.md#update_bulk_containers) | **PUT** /containers/bulk/{versionId}/{parentId} | Bulk edit containers.
*ContainersApi* | [**update_container**](docs/ContainersApi.md#update_container) | **PUT** /containers/{versionId}/{containerId} | Edit a container.
*DataProcessingApi* | [**create_dp**](docs/DataProcessingApi.md#create_dp) | **POST** /dataProcessing/{versionId}/{parentId} | Create a data processing.
*DataProcessingApi* | [**data_processing_bulk_creation**](docs/DataProcessingApi.md#data_processing_bulk_creation) | **POST** /dataProcessing/bulktree/{versionId} | Bulk upsert data processing tree
*DataProcessingApi* | [**delete_bulk_dp**](docs/DataProcessingApi.md#delete_bulk_dp) | **DELETE** /dataProcessing/bulk/{versionId} | Bulk delete data processings
*DataProcessingApi* | [**delete_dp**](docs/DataProcessingApi.md#delete_dp) | **DELETE** /dataProcessing/{versionId}/{dataProcessingId} | Delete a data processing.
*DataProcessingApi* | [**get_dp**](docs/DataProcessingApi.md#get_dp) | **GET** /dataProcessing/{versionId}/{dataProcessingId} | Return a data processing.
*DataProcessingApi* | [**get_dp_list**](docs/DataProcessingApi.md#get_dp_list) | **GET** /dataProcessing | Return a list of data processing.
*DataProcessingApi* | [**get_types**](docs/DataProcessingApi.md#get_types) | **GET** /dataProcessing/types | List the data processing types.
*DataProcessingApi* | [**update_dp**](docs/DataProcessingApi.md#update_dp) | **PUT** /dataProcessing/{versionId}/{dataProcessingId} | Update a data processing.
*DataProcessingItemApi* | [**bulk_dpi_creation**](docs/DataProcessingItemApi.md#bulk_dpi_creation) | **POST** /dataProcessingItem/bulk/{versionId}/{dataProcessingId} | Bulk upsert data processing items.
*DataProcessingItemApi* | [**create_dpi**](docs/DataProcessingItemApi.md#create_dpi) | **POST** /dataProcessingItem/{versionId}/{dataProcessingId} | Create a data processing item.
*DataProcessingItemApi* | [**delete_dpi**](docs/DataProcessingItemApi.md#delete_dpi) | **DELETE** /dataProcessingItem/{versionId}/{dataProcessingId}/{dataProcessingItemId} | Delete a data processing item.
*DataProcessingItemApi* | [**get_dpi_list**](docs/DataProcessingItemApi.md#get_dpi_list) | **GET** /dataProcessingItem | Return the list of dataProcessingItems contained in the specified data processing.
*DataProcessingItemApi* | [**get_types**](docs/DataProcessingItemApi.md#get_types) | **GET** /dataProcessingItem/types | List the data processing items types.
*DataProcessingItemApi* | [**update_dpi**](docs/DataProcessingItemApi.md#update_dpi) | **PUT** /dataProcessingItem/{versionId}/{dataProcessingId}/{dataProcessingItemId} | Update a data processing item.
*FieldsApi* | [**create_field**](docs/FieldsApi.md#create_field) | **POST** /fields/{versionId}/{structureId} | Create a field.
*FieldsApi* | [**creation_bulk_fields**](docs/FieldsApi.md#creation_bulk_fields) | **POST** /fields/bulk/{versionId}/{parentId} | Bulk create fields.
*FieldsApi* | [**delete_bulk_field**](docs/FieldsApi.md#delete_bulk_field) | **DELETE** /fields/bulk/{versionId} | Bulk delete fields
*FieldsApi* | [**delete_fields**](docs/FieldsApi.md#delete_fields) | **DELETE** /fields/{versionId}/{fieldId} | Delete a field.
*FieldsApi* | [**get_field**](docs/FieldsApi.md#get_field) | **GET** /fields/{versionId}/{fieldId} | Return a field.
*FieldsApi* | [**get_fields_list**](docs/FieldsApi.md#get_fields_list) | **GET** /fields | Return a list of fields.
*FieldsApi* | [**get_types**](docs/FieldsApi.md#get_types) | **GET** /fields/types | List the field types.
*FieldsApi* | [**update_bulk_fields**](docs/FieldsApi.md#update_bulk_fields) | **PUT** /fields/bulk/{versionId}/{parentId} | Bulk edit fields.
*FieldsApi* | [**update_field**](docs/FieldsApi.md#update_field) | **PUT** /fields/{versionId}/{fieldId} | Edit a field.
*FilteredViewsApi* | [**get_filtered_view**](docs/FilteredViewsApi.md#get_filtered_view) | **GET** /filteredViews/{filteredViewId} | Fetch FilteredView
*GlossaryApi* | [**create_local_synonym**](docs/GlossaryApi.md#create_local_synonym) | **POST** /properties/localSynonyms/{versionId}/{propertyId} | Create a local synonym
*GlossaryApi* | [**create_properties_bulk_tree**](docs/GlossaryApi.md#create_properties_bulk_tree) | **POST** /properties/bulktree/{versionId} | Bulk upsert a property tree
*GlossaryApi* | [**create_property**](docs/GlossaryApi.md#create_property) | **POST** /properties/{versionId}/{parentId} | Create a property.
*GlossaryApi* | [**delete_bulk_property**](docs/GlossaryApi.md#delete_bulk_property) | **DELETE** /properties/bulk/{versionId} | Bulk delete properties
*GlossaryApi* | [**delete_local_synonym**](docs/GlossaryApi.md#delete_local_synonym) | **DELETE** /properties/localSynonyms/{versionId}/{localSynonymId} | Delete a local synonym
*GlossaryApi* | [**delete_property**](docs/GlossaryApi.md#delete_property) | **DELETE** /properties/{versionId}/{propertyId} | Delete a property.
*GlossaryApi* | [**get_local_synonyms**](docs/GlossaryApi.md#get_local_synonyms) | **GET** /properties/localSynonyms/{versionId}/{propertyId} | Get local synonyms
*GlossaryApi* | [**get_properties_list**](docs/GlossaryApi.md#get_properties_list) | **GET** /properties | Return a list of properties.
*GlossaryApi* | [**get_property**](docs/GlossaryApi.md#get_property) | **GET** /properties/{versionId}/{propertyId} | Return a property.
*GlossaryApi* | [**get_types**](docs/GlossaryApi.md#get_types) | **GET** /properties/types | List the property types.
*GlossaryApi* | [**udpate_local_synonym**](docs/GlossaryApi.md#udpate_local_synonym) | **PUT** /properties/localSynonyms/{versionId}/{localSynonymId} | Update a local synonym
*GlossaryApi* | [**update_property**](docs/GlossaryApi.md#update_property) | **PUT** /properties/{versionId}/{propertyId} | Edit a property.
*HistoryApi* | [**objects_history**](docs/HistoryApi.md#objects_history) | **GET** /history/objects | Return recently accessed objects
*HistoryApi* | [**queries_history**](docs/HistoryApi.md#queries_history) | **GET** /history/search/queries | Return saved search queries
*ImageApi* | [**get_image**](docs/ImageApi.md#get_image) | **GET** /image | Fetch an image
*ImageApi* | [**upload_image**](docs/ImageApi.md#upload_image) | **POST** /image | Upload an image
*LicensesApi* | [**get_licences_list**](docs/LicensesApi.md#get_licences_list) | **GET** /licenses | Return the list of licences owned by your account.
*LinksApi* | [**create_bulk_links**](docs/LinksApi.md#create_bulk_links) | **POST** /links/bulk/{versionId} | Bulk create links using entityIds
*LinksApi* | [**create_link**](docs/LinksApi.md#create_link) | **POST** /links/{versionId}/{fromId} | Create an entity link.
*LinksApi* | [**create_links_bulktree**](docs/LinksApi.md#create_links_bulktree) | **POST** /links/bulktree/{versionId} | Bulk create links using Paths
*LinksApi* | [**delete_link**](docs/LinksApi.md#delete_link) | **DELETE** /links/{versionId}/{fromId}/{linkType}/{toId} | Delete a link.
*LinksApi* | [**get_links**](docs/LinksApi.md#get_links) | **GET** /links/{versionId}/{fromId} | Return a list of links.
*SCIMUsersApi* | [**delete_user**](docs/SCIMUsersApi.md#delete_user) | **DELETE** /scim/Users/{userId} | Delete a user
*SCIMUsersApi* | [**get_user**](docs/SCIMUsersApi.md#get_user) | **GET** /scim/Users/{userId} | Return a user.
*SCIMUsersApi* | [**get_users**](docs/SCIMUsersApi.md#get_users) | **GET** /scim/Users | Return a list of users.
*SCIMUsersApi* | [**patch_user**](docs/SCIMUsersApi.md#patch_user) | **PATCH** /scim/Users/{userId} | Patch a user.
*SCIMUsersApi* | [**post_user**](docs/SCIMUsersApi.md#post_user) | **POST** /scim/Users | Create a user.
*ScreensApi* | [**get_attributes_screens**](docs/ScreensApi.md#get_attributes_screens) | **GET** /attributes/screens | Return a list of attribute screen layouts
*ScreensApi* | [**get_attributes_screens_data_type**](docs/ScreensApi.md#get_attributes_screens_data_type) | **GET** /attributes/screens/{dataType} | Return a list of attribute screen layouts filtered by dataType
*ScreensApi* | [**get_attributes_screens_full_types**](docs/ScreensApi.md#get_attributes_screens_full_types) | **GET** /attributes/screens/{dataType}/{type} | Return a list of attribute screen layouts filtered by dataType and entity type
*ScreensApi* | [**reset_screen**](docs/ScreensApi.md#reset_screen) | **DELETE** /attributes/screens/{dataType}/{type} | Reset an Attribute Screen
*ScreensApi* | [**update_screen**](docs/ScreensApi.md#update_screen) | **PUT** /attributes/screens/{dataType}/{type} | Update an attribute screen layout
*SearchApi* | [**search**](docs/SearchApi.md#search) | **POST** /search | Search DataGalaxy objects
*SourcesApi* | [**create_bulk_sources**](docs/SourcesApi.md#create_bulk_sources) | **POST** /sources/bulk/{versionId} | Bulk create sources.
*SourcesApi* | [**create_fk**](docs/SourcesApi.md#create_fk) | **PUT** /sources/{versionId}/{sourceId}/foreignKeys | Update/create the foreign keys of a relational source.
*SourcesApi* | [**create_pk**](docs/SourcesApi.md#create_pk) | **PUT** /sources/{versionId}/{sourceId}/primaryKeys | Update/create the primary keys of a relational source.
*SourcesApi* | [**create_sources**](docs/SourcesApi.md#create_sources) | **POST** /sources/{versionId} | Create a source.
*SourcesApi* | [**create_sources_bulk_tree**](docs/SourcesApi.md#create_sources_bulk_tree) | **POST** /sources/bulktree/{versionId} | Bulk upsert a dictionary entities tree
*SourcesApi* | [**delete_bulk_source**](docs/SourcesApi.md#delete_bulk_source) | **DELETE** /sources/bulk/{versionId} | Bulk delete sources
*SourcesApi* | [**delete_fk**](docs/SourcesApi.md#delete_fk) | **DELETE** /sources/{versionId}/{sourceId}/foreignKey/{foreignKeyId} | Delete a foreignKey.
*SourcesApi* | [**delete_pk**](docs/SourcesApi.md#delete_pk) | **DELETE** /sources/{versionId}/{sourceId}/privateKey/{columnId} | Remove column from privateKey.
*SourcesApi* | [**delete_source**](docs/SourcesApi.md#delete_source) | **DELETE** /sources/{versionId}/{sourceId} | Delete a source.
*SourcesApi* | [**get_fk**](docs/SourcesApi.md#get_fk) | **GET** /sources/{versionId}/{sourceId}/foreignKeys | Get Foreign Keys list.
*SourcesApi* | [**get_pk**](docs/SourcesApi.md#get_pk) | **GET** /sources/{versionId}/{sourceId}/primaryKey | Get Primary Keys list.
*SourcesApi* | [**get_source**](docs/SourcesApi.md#get_source) | **GET** /sources/{versionId}/{sourceId} | Return a source.
*SourcesApi* | [**get_sources_list**](docs/SourcesApi.md#get_sources_list) | **GET** /sources | Return a list of sources.
*SourcesApi* | [**get_types**](docs/SourcesApi.md#get_types) | **GET** /sources/types | List the source types.
*SourcesApi* | [**update_bulk_source**](docs/SourcesApi.md#update_bulk_source) | **PUT** /sources/bulk/{versionId} | Bulk edit sources.
*SourcesApi* | [**update_source**](docs/SourcesApi.md#update_source) | **PUT** /sources/{versionId}/{sourceId} | Edit a source.
*StructuresApi* | [**create_structure**](docs/StructuresApi.md#create_structure) | **POST** /structures/{versionId}/{parentId} | Create a structure.
*StructuresApi* | [**creation_bulk_structures**](docs/StructuresApi.md#creation_bulk_structures) | **POST** /structures/bulk/{versionId}/{parentId} | Bulk create structures
*StructuresApi* | [**delete_bulk_structure**](docs/StructuresApi.md#delete_bulk_structure) | **DELETE** /structures/bulk/{versionId} | Bulk delete structures
*StructuresApi* | [**delete_structure**](docs/StructuresApi.md#delete_structure) | **DELETE** /structures/{versionId}/{structureId} | Delete a structure.
*StructuresApi* | [**get_structure**](docs/StructuresApi.md#get_structure) | **GET** /structures/{versionId}/{structureId} | Return a structure.
*StructuresApi* | [**get_structures_list**](docs/StructuresApi.md#get_structures_list) | **GET** /structures | Return a list of structures.
*StructuresApi* | [**get_types**](docs/StructuresApi.md#get_types) | **GET** /structures/types | List the structure types.
*StructuresApi* | [**update_bulk_structures**](docs/StructuresApi.md#update_bulk_structures) | **PUT** /structures/bulk/{versionId}/{parentId} | Bulk edit structures
*StructuresApi* | [**update_structure**](docs/StructuresApi.md#update_structure) | **PUT** /structures/{versionId}/{structureId} | Edit a structure.
*TasksApi* | [**delete_task**](docs/TasksApi.md#delete_task) | **DELETE** /tasks/{versionId}/{entityId}/{taskId} | Delete a task.
*TasksApi* | [**get_task**](docs/TasksApi.md#get_task) | **GET** /tasks/{versionId}/{entityId} | List entity tasks
*TasksApi* | [**get_user_tasks**](docs/TasksApi.md#get_user_tasks) | **GET** /tasks | List user tasks
*TasksApi* | [**post_task**](docs/TasksApi.md#post_task) | **POST** /tasks/{versionId}/{entityId} | Create a task.
*TasksApi* | [**put_task**](docs/TasksApi.md#put_task) | **PUT** /tasks/{versionId}/{entityId}/{taskId} | Update a task.
*TeamsApi* | [**bulk_delete_teams**](docs/TeamsApi.md#bulk_delete_teams) | **DELETE** /teams/bulk | Delete multiple teams
*TeamsApi* | [**create_team**](docs/TeamsApi.md#create_team) | **POST** /teams | Create team
*TeamsApi* | [**delete_team**](docs/TeamsApi.md#delete_team) | **DELETE** /teams/{id} | Delete a team
*TeamsApi* | [**list_teams**](docs/TeamsApi.md#list_teams) | **GET** /teams | List teams
*TeamsApi* | [**update_team**](docs/TeamsApi.md#update_team) | **PUT** /teams/{id} | Update team
*TechnologiesApi* | [**create_techonogy**](docs/TechnologiesApi.md#create_techonogy) | **POST** /technologies | 
*TechnologiesApi* | [**delete_technology**](docs/TechnologiesApi.md#delete_technology) | **DELETE** /technologies/{technologyCode} | 
*TechnologiesApi* | [**get_technologies**](docs/TechnologiesApi.md#get_technologies) | **GET** /technologies | 
*TechnologiesApi* | [**update_technology**](docs/TechnologiesApi.md#update_technology) | **PUT** /technologies/{technologyCode} | 
*UsageApi* | [**create_usages**](docs/UsageApi.md#create_usages) | **POST** /usages/{versionId}/{parentId} | Create a usage.
*UsageApi* | [**create_usages_bulk_tree**](docs/UsageApi.md#create_usages_bulk_tree) | **POST** /usages/bulktree/{versionId} | Bulk upsert a usage tree
*UsageApi* | [**delete_bulk_usage**](docs/UsageApi.md#delete_bulk_usage) | **DELETE** /usages/bulk/{versionId} | Bulk delete usages
*UsageApi* | [**delete_usage**](docs/UsageApi.md#delete_usage) | **DELETE** /usages/{versionId}/{usageId} | Delete a usage.
*UsageApi* | [**get_types**](docs/UsageApi.md#get_types) | **GET** /usages/types | List the usage types.
*UsageApi* | [**get_usage**](docs/UsageApi.md#get_usage) | **GET** /usages/{versionId}/{usageId} | Return a usage.
*UsageApi* | [**get_usages_list**](docs/UsageApi.md#get_usages_list) | **GET** /usages | Return a list of usages.
*UsageApi* | [**update_usage**](docs/UsageApi.md#update_usage) | **PUT** /usages/{versionId}/{usageId} | Edit a usage.
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /users | Create a user.
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /users/{userId} | Delete a user
*UsersApi* | [**get_candidates**](docs/UsersApi.md#get_candidates) | **GET** /users/{versionId} | Return a list of users eligible to be stewards or owners.
*UsersApi* | [**get_client_users**](docs/UsersApi.md#get_client_users) | **GET** /users | Return a list of users.
*UsersApi* | [**get_users_authorizations**](docs/UsersApi.md#get_users_authorizations) | **GET** /users/authorizations | Return a list of users with their authorizations.
*UsersApi* | [**get_users_roles**](docs/UsersApi.md#get_users_roles) | **GET** /users/roles | Fetch governance users
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /users/{userId} | Update the properties of a user.
*UsersApi* | [**update_users_authorizations**](docs/UsersApi.md#update_users_authorizations) | **PUT** /users/authorizations | Update the authorizations of a list of users
*WorkspacesApi* | [**get_versions**](docs/WorkspacesApi.md#get_versions) | **GET** /workspaces/{workspaceId}/versions | Lists the versions of a workspace.
*WorkspacesApi* | [**get_workspaces**](docs/WorkspacesApi.md#get_workspaces) | **GET** /workspaces | List all workspaces.

## Documentation For Models

 - [AccessData](docs/AccessData.md)
 - [AccessType](docs/AccessType.md)
 - [AdditionalCustomAttribute](docs/AdditionalCustomAttribute.md)
 - [AdditionalCustomAttributeBulk](docs/AdditionalCustomAttributeBulk.md)
 - [AllTypes](docs/AllTypes.md)
 - [AllTypesLower](docs/AllTypesLower.md)
 - [AnyOfAttributeBulkCreationBodyDefaultValue](docs/AnyOfAttributeBulkCreationBodyDefaultValue.md)
 - [AnyOfAttributeBulkUpdateBodyDefaultValue](docs/AnyOfAttributeBulkUpdateBodyDefaultValue.md)
 - [AnyOfAttributeCreationBodyDefaultValue](docs/AnyOfAttributeCreationBodyDefaultValue.md)
 - [AnyOfAttributeDefaultValue](docs/AnyOfAttributeDefaultValue.md)
 - [AnyOfAttributeUpdateBodyDefaultValue](docs/AnyOfAttributeUpdateBodyDefaultValue.md)
 - [AnyOfCategoryAttributeId](docs/AnyOfCategoryAttributeId.md)
 - [AnyOfCategoryBodyAttributeNameId](docs/AnyOfCategoryBodyAttributeNameId.md)
 - [AnyOfSCIMPatchOperationPayloadOperationsValue](docs/AnyOfSCIMPatchOperationPayloadOperationsValue.md)
 - [AnyOfSearchFilterValues](docs/AnyOfSearchFilterValues.md)
 - [AnyOfTagsBodyColor](docs/AnyOfTagsBodyColor.md)
 - [ApiErrorModel](docs/ApiErrorModel.md)
 - [ApiErrorModelError](docs/ApiErrorModelError.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeBulkCreationBody](docs/AttributeBulkCreationBody.md)
 - [AttributeBulkUpdateBody](docs/AttributeBulkUpdateBody.md)
 - [AttributeCreationBody](docs/AttributeCreationBody.md)
 - [AttributeDataTypeEnum](docs/AttributeDataTypeEnum.md)
 - [AttributeFormats](docs/AttributeFormats.md)
 - [AttributeKey](docs/AttributeKey.md)
 - [AttributeName](docs/AttributeName.md)
 - [AttributeUpdateBody](docs/AttributeUpdateBody.md)
 - [AttributeValue](docs/AttributeValue.md)
 - [AttributesLayout](docs/AttributesLayout.md)
 - [AttributesResponseBody](docs/AttributesResponseBody.md)
 - [AttributesValuesBody](docs/AttributesValuesBody.md)
 - [AttributesValuesBody1](docs/AttributesValuesBody1.md)
 - [Authorizations](docs/Authorizations.md)
 - [AuthorizationsAuthorizations](docs/AuthorizationsAuthorizations.md)
 - [BulkDeleteResponse](docs/BulkDeleteResponse.md)
 - [BulkInput](docs/BulkInput.md)
 - [BulkLinksPayload](docs/BulkLinksPayload.md)
 - [BulkLinksResult](docs/BulkLinksResult.md)
 - [BulkResult](docs/BulkResult.md)
 - [BulkTreeCreationRequest](docs/BulkTreeCreationRequest.md)
 - [CategoryAttribute_](docs/CategoryAttribute_.md)
 - [CategoryBodyAttributeName_](docs/CategoryBodyAttributeName_.md)
 - [ChildContainer](docs/ChildContainer.md)
 - [ChildStructure](docs/ChildStructure.md)
 - [Color](docs/Color.md)
 - [ColumnDataType](docs/ColumnDataType.md)
 - [CommentPayload](docs/CommentPayload.md)
 - [CompatibilityDefinition](docs/CompatibilityDefinition.md)
 - [CompatibleLink](docs/CompatibleLink.md)
 - [ContainerBulkCreation](docs/ContainerBulkCreation.md)
 - [ContainerBulkUpdate](docs/ContainerBulkUpdate.md)
 - [ContainerCreationRequest](docs/ContainerCreationRequest.md)
 - [ContainerType](docs/ContainerType.md)
 - [CreateTechnologyBody](docs/CreateTechnologyBody.md)
 - [Credentials](docs/Credentials.md)
 - [CustomAttributeName](docs/CustomAttributeName.md)
 - [DataProcessingBulkCreation](docs/DataProcessingBulkCreation.md)
 - [DataProcessingBulkResponse](docs/DataProcessingBulkResponse.md)
 - [DataProcessingBulkResponseDetails](docs/DataProcessingBulkResponseDetails.md)
 - [DataProcessingBulkResponseDetailsDataProcessingItems](docs/DataProcessingBulkResponseDetailsDataProcessingItems.md)
 - [DataProcessingEntity](docs/DataProcessingEntity.md)
 - [DataProcessingItemType](docs/DataProcessingItemType.md)
 - [DataProcessingType](docs/DataProcessingType.md)
 - [DataTypes](docs/DataTypes.md)
 - [DataTypesClientMapping](docs/DataTypesClientMapping.md)
 - [DateISO](docs/DateISO.md)
 - [DefaultUser](docs/DefaultUser.md)
 - [DoubleUuid](docs/DoubleUuid.md)
 - [DpCreationRequest](docs/DpCreationRequest.md)
 - [DpUpdateRequest](docs/DpUpdateRequest.md)
 - [DpiBulkModel](docs/DpiBulkModel.md)
 - [DpiCreationBody](docs/DpiCreationBody.md)
 - [DpiData](docs/DpiData.md)
 - [DpiId](docs/DpiId.md)
 - [DpiInput](docs/DpiInput.md)
 - [DpiUpdateBody](docs/DpiUpdateBody.md)
 - [Email](docs/Email.md)
 - [Entity](docs/Entity.md)
 - [EntityAttributes](docs/EntityAttributes.md)
 - [EntityBase](docs/EntityBase.md)
 - [EntityDescriptor](docs/EntityDescriptor.md)
 - [EntityLocation](docs/EntityLocation.md)
 - [EntitySearchResult](docs/EntitySearchResult.md)
 - [EntityStatus](docs/EntityStatus.md)
 - [EntitySummary](docs/EntitySummary.md)
 - [ExactMatch](docs/ExactMatch.md)
 - [ExcludeTypeofAttributeDataTypeEnumAtKeyoftypeofAttributeDataTypeEnumTypeofDataTypeEnumDATAPROCESSINGITEM_](docs/ExcludeTypeofAttributeDataTypeEnumAtKeyoftypeofAttributeDataTypeEnumTypeofDataTypeEnumDATAPROCESSINGITEM_.md)
 - [FieldBulkCreation](docs/FieldBulkCreation.md)
 - [FieldBulkUpdate](docs/FieldBulkUpdate.md)
 - [FieldType](docs/FieldType.md)
 - [FieldsCreationRequest](docs/FieldsCreationRequest.md)
 - [FieldsUpdateRequest](docs/FieldsUpdateRequest.md)
 - [FilteredView](docs/FilteredView.md)
 - [FilteredViewSummary](docs/FilteredViewSummary.md)
 - [FkColumn](docs/FkColumn.md)
 - [ForeignKey](docs/ForeignKey.md)
 - [ForeignKeyPayload](docs/ForeignKeyPayload.md)
 - [GetTechnologiesResult](docs/GetTechnologiesResult.md)
 - [GovernanceUsers](docs/GovernanceUsers.md)
 - [HyperLink](docs/HyperLink.md)
 - [IAttributes](docs/IAttributes.md)
 - [IDate](docs/IDate.md)
 - [ImageBody](docs/ImageBody.md)
 - [ImageHash](docs/ImageHash.md)
 - [ImageMimeType](docs/ImageMimeType.md)
 - [ImageResult](docs/ImageResult.md)
 - [ImageUploadResponse](docs/ImageUploadResponse.md)
 - [IncludeAccessData](docs/IncludeAccessData.md)
 - [IncludeAttributes](docs/IncludeAttributes.md)
 - [IncludeLinks](docs/IncludeLinks.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse201](docs/InlineResponse201.md)
 - [IntegrationTokenRegenerationResponse](docs/IntegrationTokenRegenerationResponse.md)
 - [License](docs/License.md)
 - [LicenseLevel](docs/LicenseLevel.md)
 - [LicenseList](docs/LicenseList.md)
 - [LicenseReport](docs/LicenseReport.md)
 - [LinkedEntities](docs/LinkedEntities.md)
 - [LinkedEntity](docs/LinkedEntity.md)
 - [Links](docs/Links.md)
 - [LinksBulktreePayload](docs/LinksBulktreePayload.md)
 - [LinksCreationRequest](docs/LinksCreationRequest.md)
 - [LocalSynonym](docs/LocalSynonym.md)
 - [LocalSynonymCreationBody](docs/LocalSynonymCreationBody.md)
 - [LocalSynonymUpdateBody](docs/LocalSynonymUpdateBody.md)
 - [LowerCaseAllTypes](docs/LowerCaseAllTypes.md)
 - [MappingPath](docs/MappingPath.md)
 - [MaxDepth](docs/MaxDepth.md)
 - [Module](docs/Module.md)
 - [ModuleAuthorizations](docs/ModuleAuthorizations.md)
 - [ModuleAuthorizationsUpdate](docs/ModuleAuthorizationsUpdate.md)
 - [ModuleNames](docs/ModuleNames.md)
 - [ModuleRole](docs/ModuleRole.md)
 - [ObjectHistoryEntry](docs/ObjectHistoryEntry.md)
 - [ObjectLocation](docs/ObjectLocation.md)
 - [ObjectsHistoryResult](docs/ObjectsHistoryResult.md)
 - [OmitEntitySummaryAccessDataOrAttributesOrLinksOrChildrenCount_](docs/OmitEntitySummaryAccessDataOrAttributesOrLinksOrChildrenCount_.md)
 - [OmitSearchBodyIncludedAttributesOrIncludeAccessData_](docs/OmitSearchBodyIncludedAttributesOrIncludeAccessData_.md)
 - [OmitTeamIdOrIconHashOrMembersCount_](docs/OmitTeamIdOrIconHashOrMembersCount_.md)
 - [PaginatedResponseAttributesResponseBody_](docs/PaginatedResponseAttributesResponseBody_.md)
 - [PaginatedResponseDpiData_](docs/PaginatedResponseDpiData_.md)
 - [PaginatedResponseEntitySummary_](docs/PaginatedResponseEntitySummary_.md)
 - [PaginatedResponseTagsResponseBody_](docs/PaginatedResponseTagsResponseBody_.md)
 - [PaginatedResponseUserAuthorizations_](docs/PaginatedResponseUserAuthorizations_.md)
 - [PaginatedResponseUser_](docs/PaginatedResponseUser_.md)
 - [PaginatedResponseVersion_](docs/PaginatedResponseVersion_.md)
 - [PartialTeamCreationPayload_](docs/PartialTeamCreationPayload_.md)
 - [PickEntitySummaryExcludeKeyofEntitySummaryAccessDataOrAttributesOrLinksOrChildrenCount_](docs/PickEntitySummaryExcludeKeyofEntitySummaryAccessDataOrAttributesOrLinksOrChildrenCount_.md)
 - [PickEntitySummaryExcludeKeyofEntitySummaryLinks_](docs/PickEntitySummaryExcludeKeyofEntitySummaryLinks_.md)
 - [PickSearchBodyExcludeKeyofSearchBodyIncludedAttributesOrIncludeAccessData_](docs/PickSearchBodyExcludeKeyofSearchBodyIncludedAttributesOrIncludeAccessData_.md)
 - [PickTeamExcludeKeyofTeamIdOrIconHashOrMembersCount_](docs/PickTeamExcludeKeyofTeamIdOrIconHashOrMembersCount_.md)
 - [PkColumn](docs/PkColumn.md)
 - [PrimaryKey](docs/PrimaryKey.md)
 - [PrimaryKeyPayload](docs/PrimaryKeyPayload.md)
 - [PropertiesBulkTreeCreationRequest](docs/PropertiesBulkTreeCreationRequest.md)
 - [PropertyCreationRequest](docs/PropertyCreationRequest.md)
 - [PropertyType](docs/PropertyType.md)
 - [QueriesHistoryResult](docs/QueriesHistoryResult.md)
 - [QuickFilter](docs/QuickFilter.md)
 - [ReferenceObject](docs/ReferenceObject.md)
 - [ReferenceParents](docs/ReferenceParents.md)
 - [RichText](docs/RichText.md)
 - [Roles](docs/Roles.md)
 - [SCIMError](docs/SCIMError.md)
 - [SCIMListResponseUser_](docs/SCIMListResponseUser_.md)
 - [SCIMPatchOperationPayload](docs/SCIMPatchOperationPayload.md)
 - [SCIMPatchOperationPayloadOperations](docs/SCIMPatchOperationPayloadOperations.md)
 - [SCIMUser](docs/SCIMUser.md)
 - [SCIMUserEmails](docs/SCIMUserEmails.md)
 - [SCIMUserMeta](docs/SCIMUserMeta.md)
 - [SCIMUserName](docs/SCIMUserName.md)
 - [SCIMUserPhotos](docs/SCIMUserPhotos.md)
 - [SavedQuery](docs/SavedQuery.md)
 - [ScreenDataTypes](docs/ScreenDataTypes.md)
 - [SearchBody](docs/SearchBody.md)
 - [SearchFilter](docs/SearchFilter.md)
 - [SearchFilterOperator](docs/SearchFilterOperator.md)
 - [SearchQuery](docs/SearchQuery.md)
 - [SearchResponse](docs/SearchResponse.md)
 - [SearchResponseResult](docs/SearchResponseResult.md)
 - [SocialComment](docs/SocialComment.md)
 - [SourceBulkCreation](docs/SourceBulkCreation.md)
 - [SourceBulkUpdate](docs/SourceBulkUpdate.md)
 - [SourceCreationRequest](docs/SourceCreationRequest.md)
 - [SourceType](docs/SourceType.md)
 - [SourceUpdateRequest](docs/SourceUpdateRequest.md)
 - [StructureBulkCreation](docs/StructureBulkCreation.md)
 - [StructureBulkUpdate](docs/StructureBulkUpdate.md)
 - [StructureCreationRequest](docs/StructureCreationRequest.md)
 - [StructureType](docs/StructureType.md)
 - [StructureUpdateRequest](docs/StructureUpdateRequest.md)
 - [SystemAttribute](docs/SystemAttribute.md)
 - [TagsBody](docs/TagsBody.md)
 - [TagsResponseBody](docs/TagsResponseBody.md)
 - [Task](docs/Task.md)
 - [TaskCreationPayload](docs/TaskCreationPayload.md)
 - [TaskStatus](docs/TaskStatus.md)
 - [TaskType](docs/TaskType.md)
 - [TaskUpdatePayload](docs/TaskUpdatePayload.md)
 - [Team](docs/Team.md)
 - [TeamCreationPayload](docs/TeamCreationPayload.md)
 - [TeamId](docs/TeamId.md)
 - [TeamMember](docs/TeamMember.md)
 - [TeamRole](docs/TeamRole.md)
 - [TeamUpdatePayload](docs/TeamUpdatePayload.md)
 - [TeamsResult](docs/TeamsResult.md)
 - [Technology](docs/Technology.md)
 - [TechnologyModule](docs/TechnologyModule.md)
 - [TimeSeriesColorRule](docs/TimeSeriesColorRule.md)
 - [TimeSeriesEntry](docs/TimeSeriesEntry.md)
 - [TimeSeriesFrequency](docs/TimeSeriesFrequency.md)
 - [TimeSeriesValue](docs/TimeSeriesValue.md)
 - [URL](docs/URL.md)
 - [UpdateRequest](docs/UpdateRequest.md)
 - [UpdateTechnologyBody](docs/UpdateTechnologyBody.md)
 - [UsageBulktreeCreation](docs/UsageBulktreeCreation.md)
 - [UsageCreationRequest](docs/UsageCreationRequest.md)
 - [UsageType](docs/UsageType.md)
 - [UsageUpdateRequest](docs/UsageUpdateRequest.md)
 - [User](docs/User.md)
 - [UserAuthorizations](docs/UserAuthorizations.md)
 - [UserCreationBody](docs/UserCreationBody.md)
 - [UserUpdateAuthorizations](docs/UserUpdateAuthorizations.md)
 - [UserUpdateAuthorizationsDefinition](docs/UserUpdateAuthorizationsDefinition.md)
 - [UserUpdateBody](docs/UserUpdateBody.md)
 - [UsersUpdateAuthorizationsBody](docs/UsersUpdateAuthorizationsBody.md)
 - [Uuid](docs/Uuid.md)
 - [Version](docs/Version.md)
 - [VersionId](docs/VersionId.md)
 - [Workspace](docs/Workspace.md)
 - [WorkspaceAuthorization](docs/WorkspaceAuthorization.md)
 - [Workspaces](docs/Workspaces.md)

## Documentation For Authorization


## AccessToken


## IntegrationToken



## Author


